The IMAGE_TYPEDEP variable would make more sense to match the form of the
other image override variables, convert it to use the overrides format.

Signed-off-by: Richard Purdie <richard.pur...@linuxfoundation.org>
---
 meta/classes/image-container.bbclass           | 2 +-
 meta/classes/image-live.bbclass                | 6 +++---
 meta/classes/image.bbclass                     | 4 ++--
 meta/classes/image_types.bbclass               | 4 ++--
 meta/lib/oeqa/selftest/cases/containerimage.py | 2 +-
 meta/lib/oeqa/selftest/cases/image_typedep.py  | 4 ++--
 scripts/contrib/convert-overrides.py           | 2 +-
 7 files changed, 12 insertions(+), 12 deletions(-)

diff --git a/meta/classes/image-container.bbclass 
b/meta/classes/image-container.bbclass
index f002858bd24..3d1993576a0 100644
--- a/meta/classes/image-container.bbclass
+++ b/meta/classes/image-container.bbclass
@@ -1,6 +1,6 @@
 ROOTFS_BOOTSTRAP_INSTALL = ""
 IMAGE_TYPES_MASKED += "container"
-IMAGE_TYPEDEP_container = "tar.bz2"
+IMAGE_TYPEDEP:container = "tar.bz2"
 
 python __anonymous() {
     if "container" in d.getVar("IMAGE_FSTYPES") and \
diff --git a/meta/classes/image-live.bbclass b/meta/classes/image-live.bbclass
index fd876ed8e1c..2c948190cfe 100644
--- a/meta/classes/image-live.bbclass
+++ b/meta/classes/image-live.bbclass
@@ -42,9 +42,9 @@ INITRD_LIVE ?= 
"${DEPLOY_DIR_IMAGE}/${INITRD_IMAGE_LIVE}-${MACHINE}.${INITRAMFS_
 LIVE_ROOTFS_TYPE ?= "ext4"
 ROOTFS ?= "${IMGDEPLOYDIR}/${IMAGE_LINK_NAME}.${LIVE_ROOTFS_TYPE}"
 
-IMAGE_TYPEDEP_live = "${LIVE_ROOTFS_TYPE}"
-IMAGE_TYPEDEP_iso = "${LIVE_ROOTFS_TYPE}"
-IMAGE_TYPEDEP_hddimg = "${LIVE_ROOTFS_TYPE}"
+IMAGE_TYPEDEP:live = "${LIVE_ROOTFS_TYPE}"
+IMAGE_TYPEDEP:iso = "${LIVE_ROOTFS_TYPE}"
+IMAGE_TYPEDEP:hddimg = "${LIVE_ROOTFS_TYPE}"
 IMAGE_TYPES_MASKED += "live hddimg iso"
 
 python() {
diff --git a/meta/classes/image.bbclass b/meta/classes/image.bbclass
index 45dd56b544c..0321b4f7ae0 100644
--- a/meta/classes/image.bbclass
+++ b/meta/classes/image.bbclass
@@ -382,8 +382,8 @@ python () {
         if t.startswith("debugfs_"):
             t = t[8:]
             debug = "debugfs_"
-        deps = (d.getVar('IMAGE_TYPEDEP_' + t) or "").split()
-        vardeps.add('IMAGE_TYPEDEP_' + t)
+        deps = (d.getVar('IMAGE_TYPEDEP:' + t) or "").split()
+        vardeps.add('IMAGE_TYPEDEP:' + t)
         if baset not in typedeps:
             typedeps[baset] = set()
         deps = [debug + dep for dep in deps]
diff --git a/meta/classes/image_types.bbclass b/meta/classes/image_types.bbclass
index 3620931224e..6a88ac85adf 100644
--- a/meta/classes/image_types.bbclass
+++ b/meta/classes/image_types.bbclass
@@ -29,7 +29,7 @@ def imagetypes_getdepends(d):
         if d.getVar(var) is not None:
             deprecated.add(var)
 
-        for typedepends in (d.getVar("IMAGE_TYPEDEP_%s" % basetype) or 
"").split():
+        for typedepends in (d.getVar("IMAGE_TYPEDEP:%s" % basetype) or 
"").split():
             base, rest = split_types(typedepends)
             resttypes += rest
 
@@ -197,7 +197,7 @@ IMAGE_CMD:multiubi () {
 IMAGE_CMD:ubi () {
        multiubi_mkfs "${MKUBIFS_ARGS}" "${UBINIZE_ARGS}"
 }
-IMAGE_TYPEDEP_ubi = "ubifs"
+IMAGE_TYPEDEP:ubi = "ubifs"
 
 IMAGE_CMD:ubifs = "mkfs.ubifs -r ${IMAGE_ROOTFS} -o 
${IMGDEPLOYDIR}/${IMAGE_NAME}${IMAGE_NAME_SUFFIX}.ubifs ${MKUBIFS_ARGS}"
 
diff --git a/meta/lib/oeqa/selftest/cases/containerimage.py 
b/meta/lib/oeqa/selftest/cases/containerimage.py
index b92e520bc2b..3068c9ba26e 100644
--- a/meta/lib/oeqa/selftest/cases/containerimage.py
+++ b/meta/lib/oeqa/selftest/cases/containerimage.py
@@ -22,7 +22,7 @@ from oeqa.utils.commands import bitbake, get_bb_vars, runCmd
 #
 class ContainerImageTests(OESelftestTestCase):
 
-    # Verify that when specifying a IMAGE_TYPEDEP_ of the form "foo.bar" that
+    # Verify that when specifying a IMAGE_TYPEDEP: of the form "foo.bar" that
     # the conversion type bar gets added as a dep as well
     def test_expected_files(self):
 
diff --git a/scripts/contrib/convert-overrides.py 
b/scripts/contrib/convert-overrides.py
index 23f63a26e57..093318ddc12 100755
--- a/scripts/contrib/convert-overrides.py
+++ b/scripts/contrib/convert-overrides.py
@@ -64,7 +64,7 @@ skips = skips + ["get_appends_for_files", 
"test_doubleref_remove", "test_bitbake
 skips = skips + ["test_rpm_remove", "test_bitbakelayers_add_remove", 
"recipe_append_file", "log_data_removed", "recipe_append", 
"systemd_machine_unit_append"]
 skips = skips + ["recipetool_append", "changetype_remove", 
"try_appendfile_wc", "test_qemux86_directdisk", "test_layer_appends", 
"tgz_removed"]
 
-imagevars = ["IMAGE_CMD", "EXTRA_IMAGECMD"]
+imagevars = ["IMAGE_CMD", "EXTRA_IMAGECMD", IMAGE_TYPEDEP"]
 packagevars = packagevars + imagevars
 
 vars_re = {}
diff --git a/meta/lib/oeqa/selftest/cases/image_typedep.py 
b/meta/lib/oeqa/selftest/cases/image_typedep.py
index 52e1080f130..5b182a8f940 100644
--- a/meta/lib/oeqa/selftest/cases/image_typedep.py
+++ b/meta/lib/oeqa/selftest/cases/image_typedep.py
@@ -9,7 +9,7 @@ from oeqa.utils.commands import bitbake
 
 class ImageTypeDepTests(OESelftestTestCase):
 
     # Verify that when specifying a IMAGE_TYPEDEP_ of the form "foo.bar" that
     # the conversion type bar gets added as a dep as well
     def test_conversion_typedep_added(self):
 
@@ -22,7 +22,7 @@ LICENSE = "MIT"
 IMAGE_FSTYPES = "testfstype"
 
 IMAGE_TYPES_MASKED += "testfstype"
-IMAGE_TYPEDEP_testfstype = "tar.bz2"
+IMAGE_TYPEDEP:testfstype = "tar.bz2"
 
 inherit image
 
@@ -9,7 +9,7 @@ from oeqa.utils.commands import bitbake
 class ImageTypeDepTests(OESelftestTestCase):
 
-    # Verify that when specifying a IMAGE_TYPEDEP_ of the form "foo.bar" that
+    # Verify that when specifying a IMAGE_TYPEDEP: of the form "foo.bar" that
     # the conversion type bar gets added as a dep as well
     def test_conversion_typedep_added(self):
-- 
2.30.2

-=-=-=-=-=-=-=-=-=-=-=-
Links: You receive all messages sent to this group.
View/Reply Online (#154425): 
https://lists.openembedded.org/g/openembedded-core/message/154425
Mute This Topic: https://lists.openembedded.org/mt/84658917/21656
Group Owner: openembedded-core+ow...@lists.openembedded.org
Unsubscribe: https://lists.openembedded.org/g/openembedded-core/unsub 
[arch...@mail-archive.com]
-=-=-=-=-=-=-=-=-=-=-=-

Reply via email to